@@ -26,7 +26,6 @@
 #include "dom_position.h"
 
 #include "misc/helper.h"
-#include "misc/htmltags.h"
 #include "rendering/render_block.h"
 #include "rendering/render_line.h"
 #include "rendering/render_object.h"
@@ -177,7 +176,7 @@ ElementImpl *Position::element() const
         return 0;
 
     NodeImpl *n = node();
-    for (; n && !n->isElementNode(); n = n->parentNode()); //loop
+    for (; n && !n->isElementNode(); n = n->parentNode()) {}; //loop
 
     return static_cast<ElementImpl *>(n);
 }
